Class: PostBoost::Post

Inherits:
Object
  • Object
show all
Defined in:
lib/postboost/models/post.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Post

Initializes the object



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/postboost/models/post.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PostBoost::Post` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PostBoost::Post`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'accounts')
    if (value = attributes[:'accounts']).is_a?(Array)
      self.accounts = value
    end
  end

  if attributes.key?(:'versions')
    if (value = attributes[:'versions']).is_a?(Array)
      self.versions = value
    end
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'scheduled_at')
    self.scheduled_at = attributes[:'scheduled_at']
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'trashed')
    self.trashed = attributes[:'trashed']
  end
end

Instance Attribute Details

#accountsObject

Returns the value of attribute accounts.



24
25
26
# File 'lib/postboost/models/post.rb', line 24

def accounts
  @accounts
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/postboost/models/post.rb', line 34

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/postboost/models/post.rb', line 18

def id
  @id
end

#published_atObject

Returns the value of attribute published_at.



32
33
34
# File 'lib/postboost/models/post.rb', line 32

def published_at
  @published_at
end

#scheduled_atObject

Returns the value of attribute scheduled_at.



30
31
32
# File 'lib/postboost/models/post.rb', line 30

def scheduled_at
  @scheduled_at
end

#statusObject

Returns the value of attribute status.



22
23
24
# File 'lib/postboost/models/post.rb', line 22

def status
  @status
end

#tagsObject

Returns the value of attribute tags.



28
29
30
# File 'lib/postboost/models/post.rb', line 28

def tags
  @tags
end

#trashedObject

Returns the value of attribute trashed.



36
37
38
# File 'lib/postboost/models/post.rb', line 36

def trashed
  @trashed
end

#uuidObject

Returns the value of attribute uuid.



20
21
22
# File 'lib/postboost/models/post.rb', line 20

def uuid
  @uuid
end

#versionsObject

Returns the value of attribute versions.



26
27
28
# File 'lib/postboost/models/post.rb', line 26

def versions
  @versions
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/postboost/models/post.rb', line 236

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PostBoost.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/postboost/models/post.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/postboost/models/post.rb', line 61

def self.attribute_map
  {
    :'id' => :'id',
    :'uuid' => :'uuid',
    :'status' => :'status',
    :'accounts' => :'accounts',
    :'versions' => :'versions',
    :'tags' => :'tags',
    :'scheduled_at' => :'scheduled_at',
    :'published_at' => :'published_at',
    :'created_at' => :'created_at',
    :'trashed' => :'trashed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/postboost/models/post.rb', line 212

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/postboost/models/post.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/postboost/models/post.rb', line 82

def self.openapi_types
  {
    :'id' => :'Integer',
    :'uuid' => :'String',
    :'status' => :'PostStatus',
    :'accounts' => :'Array<Account>',
    :'versions' => :'Array<PostVersion>',
    :'tags' => :'Array<Tag>',
    :'scheduled_at' => :'Time',
    :'published_at' => :'Time',
    :'created_at' => :'Time',
    :'trashed' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/postboost/models/post.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      uuid == o.uuid &&
      status == o.status &&
      accounts == o.accounts &&
      versions == o.versions &&
      tags == o.tags &&
      scheduled_at == o.scheduled_at &&
      published_at == o.published_at &&
      created_at == o.created_at &&
      trashed == o.trashed
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/postboost/models/post.rb', line 307

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


199
200
201
# File 'lib/postboost/models/post.rb', line 199

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



205
206
207
# File 'lib/postboost/models/post.rb', line 205

def hash
  [id, uuid, status, accounts, versions, tags, scheduled_at, published_at, created_at, trashed].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



167
168
169
170
171
# File 'lib/postboost/models/post.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



283
284
285
# File 'lib/postboost/models/post.rb', line 283

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/postboost/models/post.rb', line 289

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



277
278
279
# File 'lib/postboost/models/post.rb', line 277

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



175
176
177
178
# File 'lib/postboost/models/post.rb', line 175

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end