Class: PostBoost::WorkspacesApi
- Inherits:
-
Object
- Object
- PostBoost::WorkspacesApi
- Defined in:
- lib/postboost/api/workspaces_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_user_to_workspace(workspace_uuid, workspace_user_input, opts = {}) ⇒ Object
Add user to workspace.
-
#add_user_to_workspace_with_http_info(workspace_uuid, workspace_user_input, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Add user to workspace.
-
#create_workspace(workspace_input, opts = {}) ⇒ Workspace
Create workspace Create a new workspace.
-
#create_workspace_with_http_info(workspace_input, opts = {}) ⇒ Array<(Workspace, Integer, Hash)>
Create workspace Create a new workspace.
-
#delete_workspace(workspace_uuid, opts = {}) ⇒ Object
Delete workspace.
-
#delete_workspace_with_http_info(workspace_uuid, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete workspace.
-
#delete_workspaces_bulk(delete_workspaces_bulk_request, opts = {}) ⇒ Object
Delete workspaces (bulk).
-
#delete_workspaces_bulk_with_http_info(delete_workspaces_bulk_request, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete workspaces (bulk).
-
#get_workspace(workspace_uuid, opts = {}) ⇒ Workspace
Get workspace.
-
#get_workspace_with_http_info(workspace_uuid, opts = {}) ⇒ Array<(Workspace, Integer, Hash)>
Get workspace.
-
#initialize(api_client = ApiClient.default) ⇒ WorkspacesApi
constructor
A new instance of WorkspacesApi.
-
#list_workspaces(opts = {}) ⇒ ListWorkspaces200Response
List workspaces Returns a paginated list of all workspaces.
-
#list_workspaces_with_http_info(opts = {}) ⇒ Array<(ListWorkspaces200Response, Integer, Hash)>
List workspaces Returns a paginated list of all workspaces.
-
#remove_user_from_workspace(workspace_uuid, remove_user_from_workspace_request, opts = {}) ⇒ Object
Remove user from workspace.
-
#remove_user_from_workspace_with_http_info(workspace_uuid, remove_user_from_workspace_request, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Remove user from workspace.
-
#update_workspace(workspace_uuid, workspace_input, opts = {}) ⇒ Object
Update workspace.
-
#update_workspace_user(workspace_uuid, workspace_user_input, opts = {}) ⇒ Object
Update user role in workspace.
-
#update_workspace_user_with_http_info(workspace_uuid, workspace_user_input, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Update user role in workspace.
-
#update_workspace_with_http_info(workspace_uuid, workspace_input, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Update workspace.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WorkspacesApi
Returns a new instance of WorkspacesApi.
19 20 21 |
# File 'lib/postboost/api/workspaces_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/postboost/api/workspaces_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_user_to_workspace(workspace_uuid, workspace_user_input, opts = {}) ⇒ Object
Add user to workspace
27 28 29 30 |
# File 'lib/postboost/api/workspaces_api.rb', line 27 def add_user_to_workspace(workspace_uuid, workspace_user_input, opts = {}) data, _status_code, _headers = add_user_to_workspace_with_http_info(workspace_uuid, workspace_user_input, opts) data end |
#add_user_to_workspace_with_http_info(workspace_uuid, workspace_user_input, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Add user to workspace
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/postboost/api/workspaces_api.rb', line 37 def add_user_to_workspace_with_http_info(workspace_uuid, workspace_user_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.add_user_to_workspace ...' end # verify the required parameter 'workspace_uuid' is set if @api_client.config.client_side_validation && workspace_uuid.nil? fail ArgumentError, "Missing the required parameter 'workspace_uuid' when calling WorkspacesApi.add_user_to_workspace" end # verify the required parameter 'workspace_user_input' is set if @api_client.config.client_side_validation && workspace_user_input.nil? fail ArgumentError, "Missing the required parameter 'workspace_user_input' when calling WorkspacesApi.add_user_to_workspace" end # resource path local_var_path = '/panel/workspaces/{workspaceUuid}/users'.sub('{' + 'workspaceUuid' + '}', CGI.escape(workspace_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(workspace_user_input) # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WorkspacesApi.add_user_to_workspace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#add_user_to_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_workspace(workspace_input, opts = {}) ⇒ Workspace
Create workspace Create a new workspace. Admin only.
99 100 101 102 |
# File 'lib/postboost/api/workspaces_api.rb', line 99 def create_workspace(workspace_input, opts = {}) data, _status_code, _headers = create_workspace_with_http_info(workspace_input, opts) data end |
#create_workspace_with_http_info(workspace_input, opts = {}) ⇒ Array<(Workspace, Integer, Hash)>
Create workspace Create a new workspace. Admin only.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/postboost/api/workspaces_api.rb', line 109 def create_workspace_with_http_info(workspace_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.create_workspace ...' end # verify the required parameter 'workspace_input' is set if @api_client.config.client_side_validation && workspace_input.nil? fail ArgumentError, "Missing the required parameter 'workspace_input' when calling WorkspacesApi.create_workspace" end # resource path local_var_path = '/panel/workspaces' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(workspace_input) # return_type return_type = opts[:debug_return_type] || 'Workspace' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WorkspacesApi.create_workspace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#create_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_workspace(workspace_uuid, opts = {}) ⇒ Object
Delete workspace
166 167 168 169 |
# File 'lib/postboost/api/workspaces_api.rb', line 166 def delete_workspace(workspace_uuid, opts = {}) data, _status_code, _headers = delete_workspace_with_http_info(workspace_uuid, opts) data end |
#delete_workspace_with_http_info(workspace_uuid, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete workspace
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/postboost/api/workspaces_api.rb', line 175 def delete_workspace_with_http_info(workspace_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.delete_workspace ...' end # verify the required parameter 'workspace_uuid' is set if @api_client.config.client_side_validation && workspace_uuid.nil? fail ArgumentError, "Missing the required parameter 'workspace_uuid' when calling WorkspacesApi.delete_workspace" end # resource path local_var_path = '/panel/workspaces/{workspaceUuid}'.sub('{' + 'workspaceUuid' + '}', CGI.escape(workspace_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WorkspacesApi.delete_workspace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#delete_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_workspaces_bulk(delete_workspaces_bulk_request, opts = {}) ⇒ Object
Delete workspaces (bulk)
227 228 229 230 |
# File 'lib/postboost/api/workspaces_api.rb', line 227 def delete_workspaces_bulk(delete_workspaces_bulk_request, opts = {}) data, _status_code, _headers = delete_workspaces_bulk_with_http_info(delete_workspaces_bulk_request, opts) data end |
#delete_workspaces_bulk_with_http_info(delete_workspaces_bulk_request, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete workspaces (bulk)
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/postboost/api/workspaces_api.rb', line 236 def delete_workspaces_bulk_with_http_info(delete_workspaces_bulk_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.delete_workspaces_bulk ...' end # verify the required parameter 'delete_workspaces_bulk_request' is set if @api_client.config.client_side_validation && delete_workspaces_bulk_request.nil? fail ArgumentError, "Missing the required parameter 'delete_workspaces_bulk_request' when calling WorkspacesApi.delete_workspaces_bulk" end # resource path local_var_path = '/panel/workspaces' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(delete_workspaces_bulk_request) # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WorkspacesApi.delete_workspaces_bulk", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#delete_workspaces_bulk\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_workspace(workspace_uuid, opts = {}) ⇒ Workspace
Get workspace
293 294 295 296 |
# File 'lib/postboost/api/workspaces_api.rb', line 293 def get_workspace(workspace_uuid, opts = {}) data, _status_code, _headers = get_workspace_with_http_info(workspace_uuid, opts) data end |
#get_workspace_with_http_info(workspace_uuid, opts = {}) ⇒ Array<(Workspace, Integer, Hash)>
Get workspace
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/postboost/api/workspaces_api.rb', line 302 def get_workspace_with_http_info(workspace_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.get_workspace ...' end # verify the required parameter 'workspace_uuid' is set if @api_client.config.client_side_validation && workspace_uuid.nil? fail ArgumentError, "Missing the required parameter 'workspace_uuid' when calling WorkspacesApi.get_workspace" end # resource path local_var_path = '/panel/workspaces/{workspaceUuid}'.sub('{' + 'workspaceUuid' + '}', CGI.escape(workspace_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Workspace' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WorkspacesApi.get_workspace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#get_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_workspaces(opts = {}) ⇒ ListWorkspaces200Response
List workspaces Returns a paginated list of all workspaces. Admin only.
357 358 359 360 |
# File 'lib/postboost/api/workspaces_api.rb', line 357 def list_workspaces(opts = {}) data, _status_code, _headers = list_workspaces_with_http_info(opts) data end |
#list_workspaces_with_http_info(opts = {}) ⇒ Array<(ListWorkspaces200Response, Integer, Hash)>
List workspaces Returns a paginated list of all workspaces. Admin only.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/postboost/api/workspaces_api.rb', line 369 def list_workspaces_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.list_workspaces ...' end allowable_values = ["active", "trialing", "past_due", "paused", "canceled", "incomplete"] if @api_client.config.client_side_validation && opts[:'subscription_status'] && !allowable_values.include?(opts[:'subscription_status']) fail ArgumentError, "invalid value for \"subscription_status\", must be one of #{allowable_values}" end allowable_values = ["subscription", "unlimited", "locked"] if @api_client.config.client_side_validation && opts[:'access_status'] && !allowable_values.include?(opts[:'access_status']) fail ArgumentError, "invalid value for \"access_status\", must be one of #{allowable_values}" end # resource path local_var_path = '/panel/workspaces' # query parameters query_params = opts[:query_params] || {} query_params[:'keyword'] = opts[:'keyword'] if !opts[:'keyword'].nil? query_params[:'subscription_status'] = opts[:'subscription_status'] if !opts[:'subscription_status'].nil? query_params[:'access_status'] = opts[:'access_status'] if !opts[:'access_status'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListWorkspaces200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WorkspacesApi.list_workspaces", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#list_workspaces\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_user_from_workspace(workspace_uuid, remove_user_from_workspace_request, opts = {}) ⇒ Object
Remove user from workspace
429 430 431 432 |
# File 'lib/postboost/api/workspaces_api.rb', line 429 def remove_user_from_workspace(workspace_uuid, remove_user_from_workspace_request, opts = {}) data, _status_code, _headers = remove_user_from_workspace_with_http_info(workspace_uuid, remove_user_from_workspace_request, opts) data end |
#remove_user_from_workspace_with_http_info(workspace_uuid, remove_user_from_workspace_request, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Remove user from workspace
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/postboost/api/workspaces_api.rb', line 439 def remove_user_from_workspace_with_http_info(workspace_uuid, remove_user_from_workspace_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.remove_user_from_workspace ...' end # verify the required parameter 'workspace_uuid' is set if @api_client.config.client_side_validation && workspace_uuid.nil? fail ArgumentError, "Missing the required parameter 'workspace_uuid' when calling WorkspacesApi.remove_user_from_workspace" end # verify the required parameter 'remove_user_from_workspace_request' is set if @api_client.config.client_side_validation && remove_user_from_workspace_request.nil? fail ArgumentError, "Missing the required parameter 'remove_user_from_workspace_request' when calling WorkspacesApi.remove_user_from_workspace" end # resource path local_var_path = '/panel/workspaces/{workspaceUuid}/users'.sub('{' + 'workspaceUuid' + '}', CGI.escape(workspace_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(remove_user_from_workspace_request) # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WorkspacesApi.remove_user_from_workspace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#remove_user_from_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_workspace(workspace_uuid, workspace_input, opts = {}) ⇒ Object
Update workspace
501 502 503 504 |
# File 'lib/postboost/api/workspaces_api.rb', line 501 def update_workspace(workspace_uuid, workspace_input, opts = {}) data, _status_code, _headers = update_workspace_with_http_info(workspace_uuid, workspace_input, opts) data end |
#update_workspace_user(workspace_uuid, workspace_user_input, opts = {}) ⇒ Object
Update user role in workspace
573 574 575 576 |
# File 'lib/postboost/api/workspaces_api.rb', line 573 def update_workspace_user(workspace_uuid, workspace_user_input, opts = {}) data, _status_code, _headers = update_workspace_user_with_http_info(workspace_uuid, workspace_user_input, opts) data end |
#update_workspace_user_with_http_info(workspace_uuid, workspace_user_input, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Update user role in workspace
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'lib/postboost/api/workspaces_api.rb', line 583 def update_workspace_user_with_http_info(workspace_uuid, workspace_user_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.update_workspace_user ...' end # verify the required parameter 'workspace_uuid' is set if @api_client.config.client_side_validation && workspace_uuid.nil? fail ArgumentError, "Missing the required parameter 'workspace_uuid' when calling WorkspacesApi.update_workspace_user" end # verify the required parameter 'workspace_user_input' is set if @api_client.config.client_side_validation && workspace_user_input.nil? fail ArgumentError, "Missing the required parameter 'workspace_user_input' when calling WorkspacesApi.update_workspace_user" end # resource path local_var_path = '/panel/workspaces/{workspaceUuid}/users'.sub('{' + 'workspaceUuid' + '}', CGI.escape(workspace_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(workspace_user_input) # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WorkspacesApi.update_workspace_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#update_workspace_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_workspace_with_http_info(workspace_uuid, workspace_input, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Update workspace
511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 |
# File 'lib/postboost/api/workspaces_api.rb', line 511 def update_workspace_with_http_info(workspace_uuid, workspace_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkspacesApi.update_workspace ...' end # verify the required parameter 'workspace_uuid' is set if @api_client.config.client_side_validation && workspace_uuid.nil? fail ArgumentError, "Missing the required parameter 'workspace_uuid' when calling WorkspacesApi.update_workspace" end # verify the required parameter 'workspace_input' is set if @api_client.config.client_side_validation && workspace_input.nil? fail ArgumentError, "Missing the required parameter 'workspace_input' when calling WorkspacesApi.update_workspace" end # resource path local_var_path = '/panel/workspaces/{workspaceUuid}'.sub('{' + 'workspaceUuid' + '}', CGI.escape(workspace_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(workspace_input) # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WorkspacesApi.update_workspace", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkspacesApi#update_workspace\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |